@@ -28,7 +28,7 @@ class Profile(AbstractBaseUser, core.models.Log, PermissionsMixin):
     })
 
     origem_codigo = models.CharField(null=True, max_length=200)
-    origem_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE')
+    origem_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE.ORIGEM')
     origem = CompositeForeignKey(core.models.Tipo, on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_origem', to_fields={
         "codigo": "origem_codigo",
         "tipo": "origem_tipo"
